import ImmutableXWallet from "../../wallet";
import { ImmutableMethodParams, ImmutableMethodResults, OrderParams, PositiveIntegerString, Token, TransferParams } from '@imtbl/imx-link-types';
import { AxiosRequestConfig } from 'axios';
import * as TE from 'fp-ts/lib/TaskEither';
/**
 * Immutable X REST API Client
 */
export declare class ImmutableXClient {
    version: string;
    private hostname;
    private wallet;
    private agent;
    constructor(version: string, hostname: string, wallet: ImmutableXWallet);
    buildOptions(): AxiosRequestConfig;
    private get;
    private post;
    registerF({ etherKey, starkPublicKey, }: ImmutableMethodParams.ImmutableRegisterParams): TE.TaskEither<Error, any>;
    register(params: ImmutableMethodParams.ImmutableRegisterParamsTS): Promise<any>;
    depositF({ token, starkPublicKey, quantizedAmount, vaultId, nonce, }: ImmutableMethodParams.ImmutableDepositParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableDepositResult>;
    deposit(params: ImmutableMethodParams.ImmutableDepositParamsTS): Promise<ImmutableMethodResults.ImmutableDepositResult>;
    getSignableDepositF({ etherKey, token, quantizedAmount, }: ImmutableMethodParams.ImmutableGetSignableDepositParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetSignableDepositResult>;
    getSignableDeposit(params: ImmutableMethodParams.ImmutableGetSignableDepositParamsTS): Promise<ImmutableMethodResults.ImmutableGetSignableDepositResult>;
    depositCancel(starkPublicKey: string, token: Token, vaultId: string): Promise<any>;
    depositReclaim(starkPublicKey: string, token: Token, vaultId: string): Promise<any>;
    withdrawal(starkPublicKey: string, quantizedAmount: string, token: Token, vaultId: string, nonce: string): Promise<ImmutableMethodResults.ImmutableWithdrawalResult>;
    getSignableWithdrawal(etherKey: string, token: Token, quantizedAmount: string): Promise<ImmutableMethodResults.ImmutableGetSignableWithdrawalResult>;
    transfer(from: TransferParams, to: TransferParams, token: Token, quantizedAmount: string, nonce: string, expirationTimestamp: string, signature: string): Promise<ImmutableMethodResults.ImmutableTransferResult>;
    getSignableTransfer(senderEtherKey: string, token: Token, quantizedAmount: PositiveIntegerString, receiverEtherKey: string): Promise<ImmutableMethodResults.ImmutableGetSignableTransferResult>;
    createOrder(starkPublicKey: string, sell: OrderParams, buy: OrderParams, nonce: string, expirationTimestamp: string, signature: string): Promise<ImmutableMethodResults.ImmutableCreateOrderResult>;
    getSignableOrder(etherKey: string, tokenSell: Token, amountSell: string, tokenBuy: Token, amountBuy: string): Promise<ImmutableMethodResults.ImmutableGetSignableOrderResult>;
    createTrade(starkPublicKey: string, sell: OrderParams, buy: OrderParams, nonce: string, expirationTimestamp: string, signature: string, orderId: string): Promise<any>;
    cancelOrder(starkPublicKey: string, orderId: string): Promise<any>;
    getBalancesF(params: ImmutableMethodParams.ImmutableGetBalancesParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetBalancesResult>;
    getBalances(params: ImmutableMethodParams.ImmutableGetBalancesParamsTS): Promise<ImmutableMethodResults.ImmutableGetBalancesResult>;
    getVaults(starkPublicKey: string): Promise<any>;
    getOrder(starkPublicKey: string, orderId: string): Promise<any>;
    getOrderList(): Promise<ImmutableMethodResults.ImmutableGetOrderListResult>;
    getAssetListF({ user, page_size, next_page_token, }: ImmutableMethodParams.ImmutableGetAssetListParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetAssetListResult>;
    getAssetList(params: ImmutableMethodParams.ImmutableGetAssetListParamsTS): Promise<ImmutableMethodResults.ImmutableGetAssetListResult>;
    getAsset({ address, id, }: ImmutableMethodParams.ImmutableGetAssetParams): Promise<ImmutableMethodResults.ImmutableAsset>;
    getDepositListF(query: ImmutableMethodParams.ImmutableGetDepositListParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetDepositListResult>;
    getDepositList(params: ImmutableMethodParams.ImmutableGetDepositListParamsTS): Promise<ImmutableMethodResults.ImmutableGetDepositListResult>;
    getWithdrawalList(query: ImmutableMethodParams.ImmutableGetWithdrawalListParams): Promise<ImmutableMethodResults.ImmutableGetWithdrawalListResult>;
    getTransferList(query: ImmutableMethodParams.ImmutableGetTransferListParams): Promise<ImmutableMethodResults.ImmutableGetTransferListResult>;
    getTradeList(query: ImmutableMethodParams.ImmutableGetTradeListParams): Promise<ImmutableMethodResults.ImmutableGetTradeListResult>;
    getLastAvailableNonce(starkPublicKey: string): Promise<{
        Nonce: string;
    }>;
    getTokenBody(token: Token): any;
    private decodeForFunction;
    resolve(payload: any): Promise<{
        id: any;
        result: any;
        error?: undefined;
    } | {
        id: any;
        error: {
            message: any;
        };
        result?: undefined;
    }>;
}
export default ImmutableXClient;
//# sourceMappingURL=index.d.ts.map